flutter_staggered_grid library

Classes

AlignedGridView
A scrollable, 2D array of widgets placed according to the aligned layout.
AnimatedAlignedGridView
A scrollable, 2D array of widgets placed according to an aligned layout that animates items when they are inserted or removed.
AnimatedAlignedGridViewState
AnimatedMasonryGridView
A scrollable, 2D array of widgets placed according to a masonry layout that animates items when they are inserted or removed.
AnimatedMasonryGridViewState
MasonryGridView
A scrollable, 2D array of widgets placed according to the masonry layout.
QuiltedGridRepeatPattern
Defines how a pattern is repeating.
QuiltedGridTile
A tile for SliverQuiltedGridDelegate.
RenderSliverMasonryGrid
A sliver that places multiple box children in a two dimensional arrangement.
ReorderableAlignedGridView
A scrollable, 2D array of widgets placed according to an aligned layout that allows users to interactively reorder items via drag-and-drop.
ReorderableMasonryGridView
A scrollable, 2D array of widgets placed according to a masonry layout that allows users to interactively reorder items via drag-and-drop.
SliverAlignedGrid
A sliver that places multiple box children in a two dimensional arrangement.
SliverAnimatedAlignedGrid
A sliver version of AnimatedAlignedGridView.
SliverAnimatedAlignedGridState
SliverAnimatedMasonryGrid
A sliver version of AnimatedMasonryGridView.
SliverAnimatedMasonryGridState
SliverMasonryGrid
A sliver that places multiple box children in a two dimensional arrangement.
SliverMasonryGridParentData
Parent data structure used by RenderSliverMasonryGrid.
SliverQuiltedGridDelegate
Controls the layout of a quilted grid.
SliverSimpleGridDelegate
Controls the layout of tiles in a some slivers.
SliverSimpleGridDelegateWithFixedCrossAxisCount
Creates grid layouts with a fixed number of tiles in the cross axis.
SliverSimpleGridDelegateWithMaxCrossAxisExtent
Creates grid layouts with tiles that each have a maximum cross-axis extent.
SliverStairedGridDelegate
Controls the layout of tiles in a staired grid.
SliverStickyHeader
A sliver that has a header widget that sticks to the top of the viewport while its child sliver is visible.
SliverWovenGridDelegate
Controls the layout of tiles in a woven grid.
StaggeredGrid
A grid which lays out children in a staggered arrangement. Each child can have a different size. Wrap your children with a StaggeredGridTile to specify their size if it's different from a 1x1 tile.
StaggeredGridDelegate
Controls the layout of a StaggeredGrid.
StaggeredGridDelegateWithFixedCrossAxisCount
Creates grid layouts with a fixed number of tiles in the cross axis.
StaggeredGridDelegateWithMaxCrossAxisExtent
Creates grid layouts with tiles that each have a maximum cross-axis extent.
StaggeredGridTile
Represents the size of a StaggeredGrid's tile.
StairedGridTile
A tile of a staired pattern.
WovenGridTile
A tile of a woven pattern.